@@ -6,27 +6,27 @@ class TestIsPactEnabledForServiceAndStage(unittest.TestCase):
 
     def test_pact_enabled(self):
         result = is_pact_enabled_for_service_and_stage(
-            actual_environment="test_env",
+            current_stage="test_env",
             service_name="test_service",
             pact_environments=["test_env", "prod_env"],
             is_pact_pacticipant=True,
-            pact_pacticipants=None
+            pact_pacticipants=[]
         )
         self.assertTrue(result)
 
     def test_pact_disabled(self):
         result = is_pact_enabled_for_service_and_stage(
-            actual_environment="dev_env",
+            current_stage="dev_env",
             service_name="test_service",
             pact_environments=["test_env", "prod_env"],
             is_pact_pacticipant=False,
-            pact_pacticipants=None
+            pact_pacticipants=[]
         )
         self.assertFalse(result)
 
     def test_pact_enabled_for_service(self):
         result = is_pact_enabled_for_service_and_stage(
-            actual_environment="test_env",
+            current_stage="test_env",
             service_name="test_service",
             pact_environments=["test_env", "prod_env"],
             is_pact_pacticipant=False,
